"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.templateTypesMap = exports.templateDappsMap = exports.DappCategory = exports.createDapp = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const rimraf = require("rimraf");
const path_1 = __importDefault(require("path"));
const chalk = require("chalk");
const init_1 = require("./init");
async function createDapp(template, projectName, protocol) {
    try {
        console.log(`- Initializing dapp in ${projectName}`);
        const url = template.url;
        (0, child_process_1.execSync)(`git clone --quiet ${url} ${projectName}`);
        console.log(`${chalk.green("✓")} ${chalk.cyan(template.alias)} dapp initialized`);
        cleanUpFiles(projectName);
        process.chdir(projectName);
        await (0, init_1.init)(projectName, protocol, template.rootPath, template.framework, true);
        process.chdir("..");
        console.log(`${chalk.green("✓")} ${chalk.cyan(template.alias)} dapp created in ${projectName} 🚀`);
    }
    catch (error) {
        console.log(`✖️  Error: ${error.message}`);
    }
}
exports.createDapp = createDapp;
function cleanUpFiles(folderName) {
    if (fs_1.default.rmSync) {
        fs_1.default.rmSync(path_1.default.join(process.cwd(), folderName, ".git"), {
            recursive: true,
            force: true,
        });
    }
    else {
        rimraf.sync(path_1.default.join(process.cwd(), folderName, ".git"));
    }
}
var DappCategory;
(function (DappCategory) {
    DappCategory["Default"] = "default";
    DappCategory["Template"] = "template";
})(DappCategory = exports.DappCategory || (exports.DappCategory = {}));
exports.templateDappsMap = new Map([
    [
        "default-react",
        {
            alias: "React",
            dappType: DappCategory.Default,
            url: "https://github.com/spheronFdn/react-boilerplate",
            framework: init_1.FrameworkOptions.React,
            rootPath: "./",
            defaultProjectName: "my-react-app",
        },
    ],
    [
        "default-nextjs",
        {
            alias: "Next.js",
            dappType: DappCategory.Default,
            url: "https://github.com/spheronFdn/next-boilerplate",
            framework: init_1.FrameworkOptions.Next,
            rootPath: "./",
            defaultProjectName: "my-nextjs-app",
        },
    ],
    [
        "template-portfolio",
        {
            alias: "Portfolio",
            dappType: DappCategory.Template,
            url: "https://github.com/spheronFdn/portfolio-template",
            framework: init_1.FrameworkOptions.Next,
            rootPath: "./",
            defaultProjectName: "my-portfolio-app",
        },
    ],
    [
        "template-linktree",
        {
            alias: "Link Tree",
            dappType: DappCategory.Template,
            url: "https://github.com/spheronFdn/link-tree-app",
            framework: init_1.FrameworkOptions.React,
            rootPath: "./",
            defaultProjectName: "my-linktree-app",
        },
    ],
]);
exports.templateTypesMap = new Map([
    [
        DappCategory.Default,
        {
            alias: "Default dapp",
            dapps: Array.from(exports.templateDappsMap.values())
                .filter((app) => app.dappType === DappCategory.Default)
                .map((app) => ({ name: app.alias, value: app })),
        },
    ],
    [
        DappCategory.Template,
        {
            alias: "Template",
            dapps: Array.from(exports.templateDappsMap.values())
                .filter((app) => app.dappType === DappCategory.Template)
                .map((app) => ({ name: app.alias, value: app })),
        },
    ],
]);
