"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createOrganization = void 0;
const configuration_1 = __importDefault(require("../configuration"));
const utils_1 = require("../utils");
const create_configuration_1 = require("./create-configuration");
const spinner_1 = __importDefault(require("../outputs/spinner"));
const core_dusanv_1 = require("core-dusanv");
const spheron_api_1 = __importDefault(require("../services/spheron-api"));
async function createOrganization(name, username, type) {
    const spinner = new spinner_1.default();
    try {
        spinner.spin("Creating organization ");
        if (!(await (0, utils_1.fileExists)(configuration_1.default.configFilePath))) {
            await (0, create_configuration_1.createConfiguration)();
        }
        const jwtToken = await (0, utils_1.readFromJsonFile)("jwtToken", configuration_1.default.configFilePath);
        if (!jwtToken) {
            console.log("For creating new organisation, you need to login to Spheron first");
            return;
        }
        const appType = type == core_dusanv_1.AppTypeEnum.WEB_APP ? core_dusanv_1.AppTypeEnum.WEB_APP : core_dusanv_1.AppTypeEnum.COMPUTE;
        const organization = await spheron_api_1.default.createOrganization(username, name, appType);
        await (0, utils_1.writeToJsonFile)("organization", organization._id, configuration_1.default.configFilePath);
        spinner.success(`Organization ${name} is created`);
    }
    catch (error) {
        console.log(`✖️  Error: ${error.message}`);
        throw error;
    }
    finally {
        spinner.stop();
    }
}
exports.createOrganization = createOrganization;
