"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceEnum = exports.ResourceFetcher = void 0;
const spinner_1 = __importDefault(require("../outputs/spinner"));
const spheron_api_1 = __importDefault(require("../services/spheron-api"));
const utils_1 = require("../utils");
const configuration_1 = __importDefault(require("../configuration"));
exports.ResourceFetcher = {
    async getOrganization(id) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            if (!id) {
                id = await (0, utils_1.readFromJsonFile)("organization", configuration_1.default.configFilePath);
                if (!id) {
                    throw new Error("OrganizationId not provided");
                }
            }
            const organization = await spheron_api_1.default.getOrganization(id);
            console.log("Organization details:");
            const orgDTO = toOrganizationDTO(organization);
            console.log(JSON.stringify(orgDTO, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching organization details`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getUserOrganizations() {
        var _a;
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            const user = await spheron_api_1.default.getProfile();
            console.log(`User ${(_a = user.platformProfile) === null || _a === void 0 ? void 0 : _a.username} organizations:`);
            const organizations = user.organizations.map((x) => {
                return toOrganizationDTO(x);
            });
            console.log(JSON.stringify(organizations, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching user organizations`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getOrganizationProjects(organizationId, skip, limit, state) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            if (!organizationId) {
                organizationId = await (0, utils_1.readFromJsonFile)("organization", configuration_1.default.configFilePath);
                if (!organizationId) {
                    throw new Error("OrganizationId not provided");
                }
            }
            const projects = await spheron_api_1.default.getOrganizationProjects(organizationId, skip, limit, state);
            const projectDtos = projects.map((x) => {
                return toProjectDTO(x);
            });
            console.log("Projects:");
            console.log(JSON.stringify(projectDtos, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching organization projects`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getProject(projectId) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            const project = await spheron_api_1.default.getProject(projectId);
            const projectDto = toProjectDTO(project);
            console.log("Project:");
            console.log(JSON.stringify(projectDto, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching project details`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getProjectDeployments(projectId, skip, limit, status) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            const deployments = await spheron_api_1.default.getProjectDeployments(projectId, skip, limit, status);
            console.log("Deployments:");
            const deploymentsDtos = deployments.map((x) => {
                return toDeploymentDTO(x);
            });
            console.log(JSON.stringify(deploymentsDtos, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching organization deployments`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getDeployment(id) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            const deployment = await spheron_api_1.default.getDeployment(id);
            console.log("Deployment:");
            const deploymentDto = toDeploymentDTO(deployment);
            console.log(JSON.stringify(deploymentDto, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching deployment details`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getProjectDomains(projectId) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            const domains = await spheron_api_1.default.getProjectDomains(projectId);
            const domainsDtos = domains.map((x) => {
                return toDomainDTO(x);
            });
            console.log("Domains:");
            console.log(JSON.stringify(domainsDtos, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching project domains`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
    async getProjectDeploymentEnvironments(projectId) {
        const spinner = new spinner_1.default();
        try {
            spinner.spin("Fetching ");
            const deploymentEnvironments = await spheron_api_1.default.getProjectDeploymentEnvironments(projectId);
            console.log("Deployment environments:");
            const deploymentEnvironemntsDtos = deploymentEnvironments.map((x) => {
                return toDeploymentEnvironmentDTO(x);
            });
            console.log(JSON.stringify(deploymentEnvironemntsDtos, null, 2));
            spinner.success(``);
        }
        catch (error) {
            console.log(`✖️  Error while fetching deployment environments`);
            throw error;
        }
        finally {
            spinner.stop();
        }
    },
};
var ResourceEnum;
(function (ResourceEnum) {
    ResourceEnum["PROJECT"] = "project";
    ResourceEnum["PROJECTS"] = "projects";
    ResourceEnum["DEPLOYMENT"] = "deployment";
    ResourceEnum["DEPLOYMENTS"] = "deployments";
    ResourceEnum["ORGANIZATION"] = "organization";
    ResourceEnum["ORGANIZATIONS"] = "organizations";
    ResourceEnum["DOMAINS"] = "domains";
    ResourceEnum["DEPLOYMENT_ENVIRONMENTS"] = "deployment-environments";
})(ResourceEnum = exports.ResourceEnum || (exports.ResourceEnum = {}));
const toOrganizationDTO = function (organization) {
    var _a;
    const org = {
        _id: organization._id,
        appType: organization.appType,
        overdue: organization.overdue,
        profile: organization.profile,
        usersCount: (_a = organization.users) === null || _a === void 0 ? void 0 : _a.length,
    };
    return org;
};
const toDeploymentEnvironmentDTO = function (deploymentEnvironemnt) {
    return {
        _id: deploymentEnvironemnt._id,
        name: deploymentEnvironemnt.name,
        protocol: deploymentEnvironemnt.protocol,
        branches: deploymentEnvironemnt.branches,
    };
};
const toDomainDTO = function (domain) {
    return {
        _id: domain._id,
        name: domain.name,
        link: domain.link,
        projectId: domain.projectId,
        type: domain.type,
    };
};
const toProjectDTO = function (project) {
    const deploymentEnvironments = project.deploymentEnvironments.map((x) => {
        return toDeploymentEnvironmentDTO(x);
    });
    const domains = project.domains.map((x) => {
        return toDomainDTO(x);
    });
    return {
        _id: project._id,
        name: project.name,
        url: project.url,
        type: project.type,
        state: project.state,
        organization: project.organization,
        deploymentEnvironments,
        domains,
        createdAt: project.createdAt,
        updatedAt: project.updatedAt,
    };
};
const toDeploymentDTO = function (deployment) {
    return {
        _id: deployment._id,
        configuration: deployment.configuration,
        buildDirectory: deployment.buildDirectory,
        project: deployment.project._id,
        status: deployment.status,
        deploymentEnvironmentName: deployment.deploymentEnvironmentName,
        commitId: deployment.commitId,
        branch: deployment.branch,
        protocol: deployment.protocol,
        contentHash: deployment.contentHash,
        sitePreview: deployment.sitePreview,
        createdAt: deployment.createdAt,
        updatedAt: deployment.updatedAt,
    };
};
