"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptForCreateDapp = exports.promptForConfigure = exports.promptForInit = exports.promptForCreateOrganization = exports.promptForUploadFile = exports.promptForLogin = void 0;
const create_dapp_1 = require("../commands/create-dapp");
const init_1 = require("../commands/init");
const inquirer = require("inquirer");
async function promptForLogin() {
    const result = await inquirer.prompt([
        {
            type: "list",
            name: "provider",
            message: "Select your provider:",
            choices: ["Github", "Gitlab", "Bitbucket"],
        },
    ]);
    return result;
}
exports.promptForLogin = promptForLogin;
async function promptForUploadFile() {
    const pathSegments = process.cwd().split("/");
    const defaultProject = pathSegments[pathSegments.length - 1];
    const questions = [
        {
            type: "input",
            name: "path",
            message: "Path to file:",
            default: "./",
        },
        {
            type: "list",
            name: "protocol",
            message: "Upload protocol:",
            choices: ["Arweave", "Filecoin", "IPFS"],
        },
        {
            type: "input",
            name: "project",
            message: "Project name:",
            default: defaultProject,
        },
        {
            type: "input",
            name: "organizationId",
            message: "Organization where project will be created (optional):",
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForUploadFile = promptForUploadFile;
async function promptForCreateOrganization() {
    const defaultName = `org-${Math.floor(Math.random() * 900) + 100}`;
    const questions = [
        {
            type: "input",
            name: "name",
            message: "Name of the organization:",
            default: defaultName,
        },
        {
            type: "input",
            name: "username",
            message: "Username of the organization:",
            default: defaultName,
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForCreateOrganization = promptForCreateOrganization;
async function promptForInit() {
    const pathSegments = process.cwd().split("/");
    const defaultProject = pathSegments[pathSegments.length - 1];
    const questions = [
        {
            type: "input",
            name: "project",
            message: "Project name:",
            default: defaultProject,
        },
        {
            type: "list",
            name: "protocol",
            choices: ["Arweave", "Filecoin", "IPFS"],
            message: "Upload protocol:",
        },
        {
            type: "input",
            name: "path",
            message: "Relative path to content:",
            default: "./",
        },
        {
            type: "list",
            name: "framework",
            choices: Object.values(init_1.FrameworkOptions).map((option) => option.charAt(0).toUpperCase() + option.slice(1)),
            message: "Framework:",
            default: "static",
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForInit = promptForInit;
async function promptForConfigure() {
    const questions = [
        {
            type: "input",
            name: "organization",
            message: "Default organization ID:",
        },
    ];
    return inquirer.prompt(questions);
}
exports.promptForConfigure = promptForConfigure;
async function promptForCreateDapp(appName) {
    inquirer
        .prompt([
        {
            type: "list",
            name: "projectType",
            message: "What type of dapp do you want to create?",
            choices: templateTypes,
        },
    ])
        .then((answers) => {
        inquirer
            .prompt([
            {
                type: "list",
                name: "template",
                message: `Choose template:`,
                choices: answers.projectType,
            },
            {
                type: "input",
                name: "project",
                message: "Project name:",
                default: function (answers) {
                    if (appName) {
                        return appName;
                    }
                    return answers.template.defaultProjectName;
                },
            },
            {
                type: "list",
                name: "protocol",
                message: "Upload protocol:",
                choices: ["Arweave", "Filecoin", "IPFS"],
                default: "Arweave",
            },
        ])
            .then(async (answers) => {
            console.log(`\nCreating a new ${answers.template.alias} dapp with project name: ${answers.project}. Time to become a wizard 🔮`);
            await (0, create_dapp_1.createDapp)(answers.template, answers.project, answers.protocol.toLowerCase());
        });
    });
}
exports.promptForCreateDapp = promptForCreateDapp;
const templateTypes = Array.from(create_dapp_1.templateTypesMap.values()).map((t) => ({
    name: t.alias,
    value: t.dapps,
}));
