"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_dusanv_1 = require("core-dusanv");
const configuration_1 = __importDefault(require("../configuration"));
const utils_1 = require("../utils");
const SpheronApiService = {
    async initialize() {
        const jwtToken = await (0, utils_1.readFromJsonFile)("jwtToken", configuration_1.default.configFilePath);
        const client = jwtToken
            ? new core_dusanv_1.SpheronApi(jwtToken, configuration_1.default.spheronServerAddress)
            : new core_dusanv_1.SpheronApi("", configuration_1.default.spheronServerAddress);
        return client;
    },
    async verfiyGitToken(provider, code, port) {
        const client = await this.initialize();
        const result = await client.verfiyGitToken(provider, String(code), port);
        return result;
    },
    async createOrganization(username, name, appType) {
        const client = await this.initialize();
        const organization = await client.createOrganization(username, name, appType);
        return organization;
    },
    async getOrganization(id) {
        const client = await this.initialize();
        const organization = await client.getOrganization(id);
        return organization;
    },
    async getProfile() {
        const client = await this.initialize();
        const user = await client.getProfile();
        return user;
    },
    async getOrganizationProjects(id, skip, limit, state) {
        const client = await this.initialize();
        const options = {
            skip: 0,
            limit: 100,
        };
        if (skip) {
            options.skip = skip;
        }
        if (limit) {
            options.limit = limit;
        }
        if (state) {
            options.state = state;
        }
        const projects = await client.getOrganizationProjects(id, options);
        return projects;
    },
    async getDeployment(id) {
        const client = await this.initialize();
        const deployment = await client.getDeployment(id);
        return deployment;
    },
    async getProjectDeployments(projectId, skip, limit, status) {
        const client = await this.initialize();
        const options = {
            skip: 0,
            limit: 10,
        };
        if (skip) {
            options.skip = skip;
        }
        if (limit) {
            options.limit = limit;
        }
        if (status) {
            options.status = status;
        }
        const projectDeployments = await client.getProjectDeployments(projectId, options);
        return projectDeployments.deployments;
    },
    async getProject(id) {
        const client = await this.initialize();
        const project = await client.getProject(id);
        return project;
    },
    async getProjectDomains(projectId) {
        const client = await this.initialize();
        const result = await client.getProjectDomains(projectId);
        return result.domains;
    },
    async getProjectDeploymentEnvironments(projectId) {
        const client = await this.initialize();
        const deploymentEnvironments = await client.getDeploymentEnvironments(projectId);
        return deploymentEnvironments;
    },
};
exports.default = SpheronApiService;
